==> deepin-image-viewer_5.7.4.orig.tar.xz: deepin-image-viewer-5.7.4/src/translations/deepin-image-viewer_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Resim Görüntüleyici</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Resim Görüntüleyici, şık arayüz ve pürüzsüz performansa sahip bir resim görüntüleme aracıdır.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Görseller</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Görsel bilgisi</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Temel bilgi</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Ayrıntılar</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Bu dosyada birden fazla sayfa var. Lütfen tüm sayfaları görüntülemek için Evince uygulamasını kullanın.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Dizin Aç</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Görseli görüntüleme izniniz yok</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Görsel dosya bulunamadı</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Düzenlenme tarihi</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Dosya boyutu</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Çekilme tarihi</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Pozlama kipi</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Pozlama programı</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Pozlama süresi</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flaş</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Diyafram</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Odak uzaklığı</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>En yüksek diyafram</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Ölçüm kipi</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Beyaz dengesi</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Flaş dengelemesi</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lens modeli</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Renk aralığı</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kamera modeli</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Boyutlar</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiket</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Ölçeklendirme yok</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Sayfayı görsele göre ayarla</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Görseli sayfaya göre ayarla</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Şuna ölçeklendir:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milimetre</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Santimetre</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>İnç</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Görsel Konumu</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Ölçeklendirme</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Görsel Ayarları</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Görsel Ayarları</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Panjur</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Değiştirici</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Kayar</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Halka</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>yyyy/MM/dd HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Yeni bir ad gir</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Dizin Seç</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Bu dizinin eşitlenmesi devre dışı bırakılmış</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Klasör ekle</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Dizin Eşitleme Yönetimi</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Klasör listesi boş</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Eşitlemeyi iptal et</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Görseller</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Aygıt kaldırıldı</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Bu dizin artık yok</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Hesaplanıyor...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Görsel Görüntüleniyor</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albüm</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slayt gösterisi</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Sunumu bitir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Albümden kaldır</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılanlara ekle</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılanlardan kaldır</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Duvar kağıdı olarak ayarla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Görsel bilgisi</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Önceki ekran</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Sonraki ekran</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Yeni albüm</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Yeniden adlandır</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Kısayolları görüntüle</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Tam ekrandan çık</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Uzaklaştır</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Lütfen yeni bir kısayol gir</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Kısayollar</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Görseli Görüntüle</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albüm</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Varsayılanları Geri Yükle</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slayt gösterisi</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Sunumu bitir</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Yazdır </translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Albümden kaldır</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılanlara ekle</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılanlardan kaldır</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Duvar kağıdı olarak ayarla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Görsel bilgisi</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Yeni albüm</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Yeniden adlandır</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Slayt Ayarları</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Geçiş etkisi</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Süre</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Geçiş süresi</translation>
    </message>
    <message>
        <source>second</source>
        <translation>saniye</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Sık kullandıklarım</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Boyut</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Pencereye sığdır</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Görüntü yönetimi</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Sık kullandıklarım</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Boyut</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Pencereye sığdır</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılanlardan kaldır</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılanlara ekle</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Herhangi bir görsel dosyası bulunamadı</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Görüntü Aç</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Görsel dosya bulunamadı</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Slayt Ayarları</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Etki</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Süre</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Kısayollar</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albüm</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Yeni albüm</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Çizelge</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Albüme ekle</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Yeni albüme ekle</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Tam ekrandan çık</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slayt gösterisi</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Yazdır</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Albümden kaldır</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılanlara ekle</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılanlardan kaldır</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Gezinme penceresini göster</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Gezinme penceresini gizle</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Duvar kağıdı olarak ayarla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Görsel bilgisi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Görüntü Aç</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Tüm görüntüler</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Yeniden adlandır</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Çizim</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.8.15.orig.tar.xz: deepin-image-viewer-5.8.15/src/translations/deepin-image-viewer_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Görsel dosya bulunamadı</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Görüntü Aç</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Görsel Görüntüleniyor</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam ekran</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Tam ekrandan çık</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Metni çıkar</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slayt gösterisi</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Yeniden adlandır</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Duvar kağıdı olarak ayarla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Görsel bilgisi</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Uzaklaştır</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Kısayolları görüntüle</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Resim Görüntüleyici</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Resim Görüntüleyici, şık arayüz ve pürüzsüz performansa sahip bir resim görüntüleme aracıdır.</translation>
    </message>
</context>
</TS>
